bayespy.inference.vmp.nodes.gaussian.WrapToGaussianGammaISO.broadcasting_multiplier
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianGammaISO.broadcasting_multiplier